==> openGion7.0.0.0_dev.zip: uap/webapps/ge/db/ORACLE/sql/install/01_TABLE/GE82S.sql <==
/****************************************************************************/
/* GE82 ( DB定義書管理テーブル )                                            */
/*                                                                          */
/* Created : 2018/09/28 16:03:20                                            */
/****************************************************************************/

CREATE TABLE GE82 (
   SYSTEM_ID    VARCHAR2 (   10 )                   NOT NULL            /*  10 ｼｽﾃﾑID       */
 , TBLSYU       VARCHAR2 (    1 )                   NOT NULL            /*  20 ﾃｰﾌﾞﾙ種別    */
 , KBTBL        VARCHAR2 (    1 )       DEFAULT '0' NOT NULL            /*  30 ﾃｰﾌﾞﾙ区分    */
 , TABLE_NAME   VARCHAR2 (   50 )                   NOT NULL            /*  40 ﾃｰﾌﾞﾙ名      */
 , NAME_JA      VARCHAR2 (  200 )                                       /*  50 名称         */
 , SEQNO        NUMBER   (    7 )       DEFAULT 0   NOT NULL            /*  60 表示順       */
 , CLM_NAME     VARCHAR2 (  120 )                                       /*  70 項目名(漢字) */
 , CLM          VARCHAR2 (   30 )                   NOT NULL            /*  80 項目         */
 , CLS_NAME     VARCHAR2 (   10 )                   NOT NULL            /*  90 DBｸﾗｽ        */
 , VIEW_LENGTH  VARCHAR2 (   10 )                                       /* 100 表示桁数     */
 , USE_LENGTH   VARCHAR2 (    9 )                                       /* 110 使用桁数     */
 , UK           VARCHAR2 (    2 )                                       /* 120 ﾕﾆｰｸｷｰ       */
 , LUK          VARCHAR2 (    2 )                                       /* 130 論理ﾕﾆｰｸｷｰ   */
 , IXA          VARCHAR2 (    2 )                                       /* 140 ｲﾝﾃﾞｯｸｽA     */
 , IXB          VARCHAR2 (    2 )                                       /* 150 ｲﾝﾃﾞｯｸｽB     */
 , IXC          VARCHAR2 (    2 )                                       /* 160 ｲﾝﾃﾞｯｸｽC     */
 , IXD          VARCHAR2 (    2 )                                       /* 170 ｲﾝﾃﾞｯｸｽD     */
 , IXE          VARCHAR2 (    2 )                                       /* 180 ｲﾝﾃﾞｯｸｽE     */
 , IXF          VARCHAR2 (    2 )                                       /* 190 ｲﾝﾃﾞｯｸｽF     */
 , IXG          VARCHAR2 (    2 )                                       /* 200 ｲﾝﾃﾞｯｸｽG     */
 , IXH          VARCHAR2 (    2 )                                       /* 210 ｲﾝﾃﾞｯｸｽH     */
 , IXI          VARCHAR2 (    2 )                                       /* 220 ｲﾝﾃﾞｯｸｽI     */
 , IXJ          VARCHAR2 (    2 )                                       /* 230 ｲﾝﾃﾞｯｸｽJ     */
 , IXK          VARCHAR2 (    2 )                                       /* 240 ｲﾝﾃﾞｯｸｽK     */
 , NOT_NULL     VARCHAR2 (    1 )                                       /* 250 ﾉｯﾄﾇﾙ        */
 , RENDERER     VARCHAR2 (   10 )                                       /* 260 表示種別     */
 , EDITOR       VARCHAR2 (   10 )                                       /* 270 編集種別     */
 , DBTYPE       VARCHAR2 (   10 )                                       /* 280 文字種別     */
 , DATA_DEFAULT VARCHAR2 (  200 )                                       /* 290 初期値       */
 , KBCLM        VARCHAR2 (    1 )       DEFAULT '0' NOT NULL            /* 300 ｶﾗﾑ区分      */
 , BIKO         VARCHAR2 ( 2000 )                                       /* 310 備考         */
 , CDKH         VARCHAR2 (    1 )                                       /* 320 改廃ｺｰﾄﾞ     */
 , COMMENTS     VARCHAR2 (  500 )                                       /* 330 ｺﾒﾝﾄ         */
 , UNIQ         NUMBER   (    9 )       DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR2 (    1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR2 (   14 )                                       /* 820 登録日時     */
 , PGSET        VARCHAR2 (   10 )                                       /* 830 作成PG       */
 , PGPSET       VARCHAR2 (   10 )                                       /* 840 作成親PG     */
 , USRSET       VARCHAR2 (   10 )                                       /* 850 作成者       */
 , DYUPD        VARCHAR2 (   14 )                                       /* 860 更新日時     */
 , PGUPD        VARCHAR2 (   10 )                                       /* 870 更新PG       */
 , PGPUPD       VARCHAR2 (   10 )                                       /* 880 更新親PG     */
 , USRUPD       VARCHAR2 (   10 )                                       /* 890 更新者       */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K );


CREATE SEQUENCE GE82S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;


CREATE OR REPLACE TRIGGER GE82T00 
  BEFORE INSERT ON GE82
  FOR EACH ROW 
  BEGIN 
    SELECT GE82S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/

==> openGion7.2.9.5_dev.zip: uap/webapps/ge/db/ORACLE/sql/install/01_TABLE/GE82S.sql <==
/****************************************************************************/
/* GE82 ( DB定義書管理テーブル )                                            */
/*                                                                          */
/* Created : 2020/11/27 10:18:50                                            */
/****************************************************************************/

CREATE TABLE GE82 (
   SYSTEM_ID    VARCHAR2 (   10 )                   NOT NULL            /*  10 ｼｽﾃﾑID       */
 , TBLSYU       VARCHAR2 (    1 )                   NOT NULL            /*  20 ﾃｰﾌﾞﾙ種別    */
 , KBTBL        VARCHAR2 (    1 )       DEFAULT '0' NOT NULL            /*  30 ﾃｰﾌﾞﾙ区分    */
 , TABLE_NAME   VARCHAR2 (   50 )                   NOT NULL            /*  40 ﾃｰﾌﾞﾙ名      */
 , NAME_JA      VARCHAR2 (  200 )                                       /*  50 名称         */
 , SEQNO        NUMBER   (    7 )       DEFAULT 0   NOT NULL            /*  60 表示順       */
 , CLM_NAME     VARCHAR2 (  120 )                                       /*  70 項目名(漢字) */
 , CLM          VARCHAR2 (   30 )                   NOT NULL            /*  80 項目         */
 , CLS_NAME     VARCHAR2 (   10 )                   NOT NULL            /*  90 DBｸﾗｽ        */
 , VIEW_LENGTH  VARCHAR2 (   10 )                                       /* 100 表示桁数     */
 , USE_LENGTH   VARCHAR2 (    9 )                                       /* 110 使用桁数     */
 , UK           VARCHAR2 (    2 )                                       /* 120 ﾕﾆｰｸｷｰ       */
 , LUK          VARCHAR2 (    2 )                                       /* 130 論理ﾕﾆｰｸｷｰ   */
 , IXA          VARCHAR2 (    2 )                                       /* 140 ｲﾝﾃﾞｯｸｽA     */
 , IXB          VARCHAR2 (    2 )                                       /* 150 ｲﾝﾃﾞｯｸｽB     */
 , IXC          VARCHAR2 (    2 )                                       /* 160 ｲﾝﾃﾞｯｸｽC     */
 , IXD          VARCHAR2 (    2 )                                       /* 170 ｲﾝﾃﾞｯｸｽD     */
 , IXE          VARCHAR2 (    2 )                                       /* 180 ｲﾝﾃﾞｯｸｽE     */
 , IXF          VARCHAR2 (    2 )                                       /* 190 ｲﾝﾃﾞｯｸｽF     */
 , IXG          VARCHAR2 (    2 )                                       /* 200 ｲﾝﾃﾞｯｸｽG     */
 , IXH          VARCHAR2 (    2 )                                       /* 210 ｲﾝﾃﾞｯｸｽH     */
 , IXI          VARCHAR2 (    2 )                                       /* 220 ｲﾝﾃﾞｯｸｽI     */
 , IXJ          VARCHAR2 (    2 )                                       /* 230 ｲﾝﾃﾞｯｸｽJ     */
 , IXK          VARCHAR2 (    2 )                                       /* 240 ｲﾝﾃﾞｯｸｽK     */
 , NOT_NULL     VARCHAR2 (    1 )                                       /* 250 ﾉｯﾄﾇﾙ        */
 , RENDERER     VARCHAR2 (   10 )                                       /* 260 表示種別     */
 , EDITOR       VARCHAR2 (   10 )                                       /* 270 編集種別     */
 , DBTYPE       VARCHAR2 (   10 )                                       /* 280 文字種別     */
 , DATA_DEFAULT VARCHAR2 (  200 )                                       /* 290 初期値       */
 , KBCLM        VARCHAR2 (    1 )       DEFAULT '0' NOT NULL            /* 300 ｶﾗﾑ区分      */
 , BIKO         VARCHAR2 ( 2000 )                                       /* 310 備考         */
 , CDKH         VARCHAR2 (    1 )                                       /* 320 改廃ｺｰﾄﾞ     */
 , COMMENTS     VARCHAR2 (  500 )                                       /* 330 ｺﾒﾝﾄ         */
 , UNIQ         NUMBER   (    9 )       DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR2 (    1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR2 (   14 )                                       /* 820 作成日時     */
 , PGSET        VARCHAR2 (   10 )                                       /* 830 作成PG       */
 , PGPSET       VARCHAR2 (   10 )                                       /* 840 作成親PG     */
 , USRSET       VARCHAR2 (   10 )                                       /* 850 作成者       */
 , DYUPD        VARCHAR2 (   14 )                                       /* 860 更新日時     */
 , PGUPD        VARCHAR2 (   10 )                                       /* 870 更新PG       */
 , PGPUPD       VARCHAR2 (   10 )                                       /* 880 更新親PG     */
 , USRUPD       VARCHAR2 (   10 )                                       /* 890 更新者       */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K );


CREATE SEQUENCE GE82S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;


CREATE OR REPLACE TRIGGER GE82T00 
  BEFORE INSERT ON GE82
  FOR EACH ROW 
  BEGIN 
    SELECT GE82S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/
